package org.gcube.application.geoportalcommon.shared.geoportal.materialization.innerobject;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

public class FilesetDV implements Serializable {


	/**
	 * 
	 */
	private static final long serialVersionUID = -3108729581669778828L;
	private String name;
	private List<PayloadDV> listPayloads = new ArrayList<PayloadDV>();

	public FilesetDV() {

	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public List<PayloadDV> getListPayload() {
		return listPayloads;
	}

	public void addPayloadDV(PayloadDV payloadDV) {
		listPayloads.add(payloadDV);
	}

	public void addListPayloadsDV(List<PayloadDV> listPayloadsDV) {
		listPayloads.addAll(listPayloadsDV);
	}

	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("FilesetDV [name=");
		builder.append(name);
		builder.append(", listPayloads=");
		builder.append(listPayloads);
		builder.append("]");
		return builder.toString();
	}

}
